package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````)14``#0```!4@0````0`!30`(``(
M`"@`%P`6``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!@````8````!`````$````!````````````````````Q'H`
M`,1Z```%`````!````$```#,?0``S(T``,R-``!X`@``I`(```8`````$```
M`@```-1]``#4C0``U(T``/````#P````!@````0````$````3`$``$P!``!,
M`0``)````"0````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9,Q]``#,C0``S(T``#0"```T`@``!`````$````O;&EB+VQD
M+6UU<VPM87)M:&8N<V\N,0`$````%`````,```!'3E4`5MH/PP-SB)O.1(PD
M^HW5<Q7Z6Y81````3`````@````(`````9`0`"5`!(`H@!`%H(90A("!``(+
M(`2-.(`208H$"`A,````30```%$```!6````5P```%\```!@````80``````
M``!C````9`````````!E````9@```&D```````````````&O-.AJ?YI\ZM/O
M#L[>1RUOQ=\?+L6;MKB-\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MO
M0OK7A^)'Q@%8[Y=YF$_#F[OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_
MJ9R;X*<""FH:GE"_VE<;H^#[20``````````````````````````6!``````
M```#``@```````"0`````````P`2``$``````````````!(````)````````
M```````2````$```````````````$0```.T!`````````````!$```!V`0``
M```````````2````%P``````````````$@```,8!`````````````!(````?
M```````````````2`````@,`````````````$@```/H!`````````````!(`
M``#2`0`````````````2````)@``````````````(`````T#````````````
M`"$````^```````````````2````1```````````````$@```$L`````````
M`````!(```##`@`````````````2````V0(`````````````$@```%(`````
M`````````!(````5`@`````````````2````60``````````````$@```)L"
M`````````````!(```!@```````````````2````:```````````````$@``
M`+P"`````````````!(```!P```````````````2````A`(`````````````
M$@```'@``````````````!(```"!```````````````@````T@(`````````
M````$@```)T``````````````!(```"B```````````````2````DP$`````
M````````%@```*("`````````````!(```!"`@`````````````2````JP``
M````````````$@```#0"`````````````!(```!1`P`````````````2````
MK0(`````````````$0````P#`````````````!$```!F`@`````````````2
M````\`(`````````````$@````X#`````````````!$```"R````````````
M```2````NP``````````````$0```(0!`````````````!(```#-````````
M```````B````W```````````````(````/(``````````````!(```"C````
M```````````2````4@(`````````````$@```/<``````````````"````"/
M`@`````````````2````$0$`````````````$@```+<!`````````````!(`
M```6`0`````````````2````=`(`````````````$@```!P!````````````
M`!(```"F`0`````````````2````*@$`````````````$@```#L!````````
M`````!(````0`@`````````````2````(0(`````````````$@```$$!````
M`````````!(```!;`@`````````````2````RP(`````````````$@```.@"
M`````````````!(```!0`0`````````````2````"P(`````````````$@``
M`%<!`````````````!(```!>`0`````````````2````"P,`````````````
M(0```&\!`````````````!(```!9!```<)`````````0`!,`_0(``$D3``#<
M`0``$@`*`.<!``#5.````@```!(`"P"3`P``/24``*@$```2``H`:00``.$K
M``#,````$@`*`'`#``"U&P``!````!(`"@`-!```61````(````2``@`M@,`
M`.4I``#\`0``$@`*`!,$``!$D````````!``$P!!!```N1L``,@!```2``H`
M[@,``$20````````$``3`($#``!])```P````!(`"@"@`P``?1H``$@````2
M``H`J`,``&4B``!L````$@`*`,P#``#I-@``&@$``!(`"@#A`P``@1T``"0`
M```2``H`^@,``'"0````````$``3``($``#1(@``4````!(`"@!D!```<)``
M```````0`!,`-@,``$$5``!$````$@`*`"$$``"E'0``&`$``!(`"@#7`P``
M0)````0````1`!(`.@0``$20````````$``2`/,#```E%0```````!(`"@`*
M!```:38``(`````2``H`/P,``&$D```<````$@`*`%H#``#%&@``\````!(`
M"@!.!```!3@``,X````2``H`6`0``'"0````````$``3`"T$``"]'@``J`,`
M`!(`"@``;W!E;F1I<@!M96UC;7``<W1D97)R`')E86QL;V,`86-C97-S`%]?
M9&5R96=I<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M
M<V5T`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``<W1R<F-H<@!C;&]S961I<@!?
M251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!V9G!R:6YT9@!S=')C
M:'(`<F5A9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`
M7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A
M=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!M96UC<'D`<W1R;&5N`%]?<W1A
M8VM?8VAK7V9A:6P`9V5T=6ED`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI
M=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C
M;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`7V9I
M;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E
M<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E
M<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U
M8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L
M;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``<W1R8W!Y`')E861D:7(`
M<W1R=&]K`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!S<')I;G1F`%]?;&EB8U]S
M=&%R=%]M86EN`'-N<')I;G1F`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C
M+FUU<VPM87)M=C<N<V\N,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE
M8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY
M7W!A<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`7U]E;F1?7P!P87)?
M9&EE`'-H85]I;FET`%]?8G-S7W-T87)T7U\`<&%R7V1I<FYA;64`<&%R7VEN
M:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I;F%L`%]?8G-S7V5N
M9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L
M+T-/4D4``,R-```7````T(T``!<```"\CP``%P```,B/```7````U(\``!<`
M````D```%P```!"0```7````%)```!<````<D```%P```""0```7````))``
M`!<````HD```%P```"R0```7````-)```!<````XD```%P```$"0```7````
MP(\``!4%``#$CP``%08``,R/```5#@``T(\``!4?``#8CP``$R,``-R/```5
M*0``X(\``!4M``#DCP``%2\``.B/```5,0``[(\``!4R``#PCP``%38``/2/
M```5.P``^(\``!4]``#\CP``%4$``-".```6`P``U(X``!8$``#8C@``%@<`
M`-R.```6"```X(X``!8)``#DC@``%@H``.B.```6"P``[(X``!8,``#PC@``
M%@T``/2.```6#@``^(X``!80``#\C@``%A$```"/```6$@``!(\``!83```(
MCP``%A0```R/```6%0``$(\``!86```4CP``%A<``!B/```6&```'(\``!89
M```@CP``%AH``"2/```6&P``*(\``!8<```LCP``%AT``#"/```6'@``-(\`
M`!8@```XCP``%B$``#R/```6(@``0(\``!8D``!$CP``%B4``$B/```6)@``
M3(\``!8G``!0CP``%B@``%2/```6*P``6(\``!8L``!<CP``%BX``&"/```6
M,```9(\``!8Q``!HCP``%C(``&R/```6,P``<(\``!8T``!TCP``%C4``'B/
M```6-P``?(\``!8X``"`CP``%CD``(2/```6.@``B(\``!8\``",CP``%CX`
M`)"/```6/P``E(\``!9```"8CP``%D(``)R/```60P``H(\``!9$``"DCP``
M%D4``*B/```61@``K(\``!9'``"PCP``%D@``+2/```620``N(\``!9+```!
MM;WH`4!P1P3@+>4$X)_E#N"/X`CPON54?@```,:/X@?*C.)4_KSE`,:/X@?*
MC.),_KSE`,:/X@?*C.)$_KSE`,:/X@?*C.(\_KSE`,:/X@?*C.(T_KSE`,:/
MX@?*C.(L_KSE`,:/X@?*C.(D_KSE`,:/X@?*C.(<_KSE`,:/X@?*C.(4_KSE
M`,:/X@?*C.(,_KSE`,:/X@?*C.($_KSE`,:/X@?*C.+\_;SE`,:/X@?*C.+T
M_;SE`,:/X@?*C.+L_;SE`,:/X@?*C.+D_;SE`,:/X@?*C.+<_;SE`,:/X@?*
MC.+4_;SE`,:/X@?*C.+,_;SE`,:/X@?*C.+$_;SE`,:/X@?*C.*\_;SE`,:/
MX@?*C.*T_;SE`,:/X@?*C.*L_;SE`,:/X@?*C.*D_;SE`,:/X@?*C.*<_;SE
M`,:/X@?*C.*4_;SE>$?]YP#&C^('RHSBB/V\Y0#&C^('RHSB@/V\Y0#&C^('
MRHSB>/V\Y0#&C^('RHSB</V\Y0#&C^('RHSB:/V\Y0#&C^('RHSB8/V\Y0#&
MC^('RHSB6/V\Y0#&C^('RHSB4/V\Y0#&C^('RHSB2/V\Y0#&C^('RHSB0/V\
MY0#&C^('RHSB./V\Y0#&C^('RHSB,/V\Y0#&C^('RHSB*/V\Y0#&C^('RHSB
M(/V\Y0#&C^('RHSB&/V\Y0#&C^('RHSB$/V\Y0#&C^('RHSB"/V\Y0#&C^('
MRHSB`/V\Y0#&C^('RHSB^/R\Y0#&C^('RHSB\/R\Y0#&C^('RHSBZ/R\Y0#&
MC^('RHSBX/R\Y0#&C^('RHSBV/R\Y0#&C^('RHSBT/R\Y7A'_><`QH_B!\J,
MXL3\O.4`QH_B!\J,XKS\O.5X1_WG`,:/X@?*C.*P_+SE`,:/X@?*C.*H_+SE
M`,:/X@?*C.*@_+SE`,:/X@?*C.*8_+SE`,:/X@?*C.*0_+SE`,:/X@?*C.*(
M_+SE`,:/X@?*C.*`_+SE`,:/X@?*C.)X_+SE`````$_T@%SPM:WK#`S,^,`/
MB[#-Z08074U>2P62?43K6`:I!:H'J%M,&V@)DT_P``/_]UCO64I\1*)86$L#
MDN-8$4881@23__?&[E5+XU@=>``M9M`=[G`O2TL'F'M$&VC26,4<DOC^,P0P
M0_`#`[#Q@$^"^/XS=]*``/_W5N\#1DE*24QZ1-_X).'?^"3!%FC=Z082"&A\
M1/Y$_$0!*L/I``Z>8,/X#,!C8&7="!\#\0P,`.N"`%'X!$^(0DSX!$_YT=0<
M`"8[3SQ)?T3X:$/X)&`J1GE$`);_][3N`"@QT#=-"*Y]1.AH__?J[@1&-$@Q
M1GA$`/`C^4"S,DM[1-AH__=F[__W(.XP2B%+>D336!IH"9M:0$_P``,RT2!&
M"[#PO?_WKNXI2GI$T&`PL__W".\52QWN<"][1!MHTUB#^,Y6B>?X:/_WZN[)
MYZAH$+$!\*/[T><>2#%&>$0`\._XJ&``*,G0\^<;2QM(XUAX1!E&`Y/_]PSN
M!"2CYP$@__?"[O_W,.\R?```5GL``%Y[```@`0``1'L``#@!```T`0````$`
M`')\``"`?```FB@``)PH``!,?```XP4``#)\``#D)0``&GP``&YZ``#N>P``
M&"4``!@!```$)P``3_``"T_P``X#27E$:$8@\`\,Y48`\`+XHG@``!"U`"0"
M1@M)"TAY1`A8A+`*2P*0RUC?^"C``Y,!E%'X#!`#1@"1`YA2^`0;__=0[@2P
M$+UV>0``$`$``/@````$`0``!D@'2P=*>$1[1(-">D0#T`5+TU@#L1A'<$<`
MO[9Z``"T>@``,'D```P!```(2`E+>$1[1!L:V0\'2@'KHP%)$'I$`]`%2]-8
M`[$81W!'`+^,>@``BGH``/QX```L`0``3_2`7!"UK>L,#,SX^`\.2PY,>T0;
M>'Q$H[D-2^-8([$,2WM$&&C_]Q3N__>Y_PI+XU@;L0E(>$3_]V#M`2((2WM$
M&G`0O0"_2GH``,9X```D`0``]GD```@!``"B9```''H``$_T@%P(M:WK#`S,
M^/@/!TL'2GM$FU@KL09)!TAY1'A$__?J[;WH"$">YP"_9G@``"@!``#@>0``
M5F0``$_T@%PMZ?A#K>L,#,SXX`\=2QY*>T2;6-/X`)"Y\0`/,-`%>(!&`"T8
MOSTM#T84OP$E`"43T=GX`$!LL4Y&*D9!1B!&__=,[1"Y8UT]*Q#05O@$3P`L
M\M$@1KWH^(,%1A7X`3\`*QB_/2OYT:7K"`7AYZ;K"08!-;80+$0^8"!&O>CX
M@TQ&Y^<H>```'`$``$_T@%P0M:WK#`S,^%@/%TH72WI$J+#36&E&&V@GDT_P
M``,$1O_WS.V@N02;`_1P0[/U($\8O[/U@$\-T`U*#$MZ1--8&F@GFUI`3_``
M`PO1*+`0O0`@\><"(2!&__>>[+#Z@/!`">GG__?6[9IW```@`0``;'<``$_T
M@%SPM:WK#`S,^$@/-$HT2WI$TUBIL!MH)Y-/\``#$+$#>`1&6[DO2BY+>D33
M6!IH)YM:0$_P``-/T2FP\+W_]U+L!48`*.[0*$;_]YKLF+/#?`#Q$P8N*P+1
M<W@`*_/0PWPN*R_0($;_]Y3M!T8P1O_WD.TX1`(P__>B[#-&!D8:22)&>43_
M]W+M,$9I1O_W0.T!,#!&!=`$FP/T<$.S]8!/%]#_]X;L,$;_]T;M*$;_]VCL
M`"C+T2A&__>D["!&__<B[:_G<W@N*\S1LW@`*[K0R.?_]Y/_YN?_]V#M(G<`
M`"`!```(=P``5B$``$_T@%PMZ?!'K>L,#,SXV`\,1E9*5DMZ1--8@K`;:`&3
M3_```PMX!48]*PB_`30@1O_W..UI1@9&*$;_]^7^34^!1G]$`"A4T/_W+.V&
M0D?9`)M/ZH,(2$O_6"MX`"L8OSTK%+\!(P`C!]`K1A/X`2\`*AB_/2KYT5L;
ML!P81#YH__<F[$;X"`#HL2A&.VA3^`@0$/@!.STK&+\`*PMP"=!*'!#X`3L1
M1@`K&+\]*P+X`3OVT3TC"D8+<!3X`3L"^`$_`"OYT2U**4MZ1--8&F@!FUI`
M3_```T71`K"]Z/"'"?'_.13X`3L)^`$_`"OYT>GG(4O_6-?X`(#8^``P>[-#
M1E/X!"])1@GQ`0D`*OC1`S&)`!I*>D03:+NY`2,(1A-@__?6ZX)&`"C,T$%&
M3^J)"$)&__?2Z\?X`*``(\WX`)`)\0$)2O@I,(;G0$;_]V;K@D8X8``HM=!/
MZHD([>>91@@AUN?_]Z3L`+\N=@``(`$```)V```<`0``>G4``,IV``!/](!<
M,+6MZPP,S/C@#Q)('>YP3WA$`&@12A))>D116(6P"D8#D1!+$$D@6'M$>43_
M]UCL"4@`)7A$`&@,2PU*#4E[1"!8>D3-Z0`U>43_]SSK!;`PO0"_P'4``)QU
M``"D=```,`$``.Q?``!"'P``,B(``)L/``!`'P``$+0,20Q*W_@TP'E$"6AZ
M1!WN<`]2^`Q`0%@B1@A+"4F#L'M$>40!E`.P7?@$2__W&;P`OTYU```V=```
M,`$``'I?``#0'@``3_2`7'"UK>L,#,SX``"L]8!<S/@``$SX*`PP2JWU`%TO
M2X:P>D336`WU`%$4,1MH"V!/\``#__?^ZBI,*DI\1`.N`T9Z1$'R`0$P1@"4
M__?4ZD'R`0-"')I".=@!,#C0#?6`51`U3_2`4BE&,$;_]W3K!!XMVV`<__<&
MZP-&0+.H0@+2`AF50B+3JT(=V$'R`0*40AS8(D881BE&__?2ZP`B`T8"51%)
M#4IY1`WU`%"*6!0P$6@":%%`3_```@K1&$8-]0!=!K!PO2H9DT+>TO_>`"/G
MY__WR.L`O]AS```@`0``KAX``)P>``!2<P``__>&OT_T@%PMZ?!/K>L,#,SX
M``!,^-`,8$RM]85=8$J#L'Q$!49?2*)8#?6%4P*O#D9X1#E&!#,2:!I@3_``
M`O_W1OTO(01&*$;_]_#JP+%52"E&>$3_]S?^*$932E!+>D0-]851TU@$,1IH
M"VA:0$_P``-`\(^`#?6%70.PO>CPCS!&__>TZDE)>43_]U;K@D8`*-S0W_@<
M@9KX`#`-\:@)^$2I\00&`"M1T"RQ448@1O_W3NH`*#[04$;_]U;K`D9#'E-$
MFD6#1CZ_`"%21`KQ`0,#TPO@DT(1<`30$O@!S;SQ+P_WT%!&__=`ZX-&*$;_
M]SSK6$0!,+#U@%^GTM_XM,!31OQ$0D9/](!1,$;-Z0#%__?XZ0$PL/6`7SS8
M.48P1O_WXNHPN5GXD#P#]'!#L_4`3QG0($D`('E$__?^ZH)&`"B#T)KX`#``
M*ZW1W+$C>"XK!=#?^&2@3_`!"_I$Q>=C>``KYM#UYP$A,$;_]\3I`"C?T1)(
M,49X1/_WH_TP1O_W-.IHY]_X/*!/\`$+^D2LY__W\.K_WNIR```@`0``TAT`
M`+P=``"L<@``EAT``((=```F'0``Y!P``*`<``"4'```;AP``$_T@%P0M:WK
M#`S,^/@/+R$$1O_W].D`L40<($:]Z!!`__?^N4_T@%PPM:WK#`S,^```3/@8
M##I*K?6`73E+@[!Z1`WU@%'36`0Q&V@+8$_P``,`*#K0`W@%1KNS__>@Z@$P
ML/6`7T?8`:PI1B!&__?`Z2!&__>4Z@$X($2@0@C9`"("X(1"0G`#T!#X`3DO
M*_C0+R$@1O_WLNEXLZ!"A+\`(P-P($;_][[I'TH=2WI$#?6`4=-8!#$::`MH
M6D!/\``#*]$-]8!=`[`PO1=*%4MZ1`WU@%'36`0Q&F@+:%I`3_```QK1$DAX
M1`WU@%T#L+WH,$#_]Y2Y`"#6YPU*"4MZ1`WU@%'36`0Q&F@+:%I`3_```P+1
M"$AX1.;G__=&Z@!Q```@`0``DG```'!P``!,&P``0'```!P;``!/](!<<+6M
MZPP,S/CH#\Q*S$MZ1,Q-TUC,3H*P?40;:`&33_```WY$;$8A1C!&__?+^["Q
MQDL`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_][7[`"CH
MT;Q.?D0A1C!&__>M^["QMTL`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K
M`"KZT2%&,$;_]Y?[`"CHT:Y.?D0A1C!&__>/^["QJ$L`F.M8&6@!ZX`#6FA!
M^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]WG[`"CHT:!.?D0A1C!&__=Q^["Q
MF4L`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]UO[`"CH
MT9).?D0A1C!&__=3^["QBDL`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K
M`"KZT2%&,$;_]SW[`"CHT81.?D0A1C!&__<U^["Q>TL`F.M8&6@!ZX`#6FA!
M^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]Q_[`"CHT79.?D0A1C!&__<7^["Q
M;$L`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]P'[`"CH
MT6A.?D0A1C!&__?Y^K"Q74L`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K
M`"KZT2%&,$;_]^/Z`"CHT5I.?D0A1C!&__?;^K"Q3DL`F.M8&6@!ZX`#6FA!
M^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]\7Z`"CHT4Q.?D0A1C!&__>]^K"Q
M/TL`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]Z?Z`"CH
MT3Y.?D0A1C!&__>?^K"Q,$L`F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K
M`"KZT2%&,$;_]XGZ`"CHT3!((49X1/_W@OH!1ABQ+4AX1/_W>/LL2"%&>$3_
M]W?Z`488L2I(>$3_]VW[*4@A1GA$__=L^@%&L+$F2'A$__=B^R5*$4MZ1--8
M&F@!FUI`3_```Q71(4DB2'E$>$0"L+WH<$#_]T^['T@A1GA$__=.^@%&`"CD
MT!Q(>$3_]T/[W^?_]YCH\F\``"`!``#H;P```AL``!P!``#0&@``G!H``&P:
M```X&@``#!H``&P9``"@&0``<!D``$`9``"(&```TA@``*X8``#0&```V!@`
M`-H8```&&```!&T``-08```Z&```KA@``#@8``!/](!<`+6MZPP,S/CP#Q-*
M$TMZ1!-(@[#36&E&>$0;:`&33_```__W^_E`L0!X`"@8OS`H#+\!(``@@/`!
M``I*!TMZ1--8&F@!FUI`3_```P+1`[!=^`3[__<VZ$IL```@`0``J!<``!IL
M``!/](!<#[0`M:WK#`S,^/`/"TD,2WE$RUB#L!MH`9-/\``#!*I2^`0;!TL(
M2'M$`)(;6!AH_O=:[_\@_O>@[P"_W&L``"`!``#$:P``_````$_P``PMZ?!'
M3_2`/JWK#`RLZPX.K/6`7,SX``#T1?G13O@X#`(A0$VM]8`]/TR&L'U$+%D-
M]8`V)&AT84_P``0`(@`C`)&`1O[WP.X!.&'Q``?Z%X#JYW.;&INR4T";&@;Q
M%`9BZP("QAIGZP('`"]+VT_P"`D#K<#R`0D`(3)&.T9`1@"1_O>B[K'Q_S\(
MO[#Q_S]!T$I&*49`1O[W7N]#'#;0!R@FV0@X+!@CTM_X@*#Z1`+@`3RL0AS3
M"")11B!&_O=.[@`H]=%D&Z`91^OD<1A*%4MZ1`WU@#336!0T&F@C:%I`3_``
M`QK1#?6`/0:PO>CPA[;U@#9G\0`'M_'_/PB_%O6`/[C13_#_,`%&W^<)2'A$
M__=+_PA(>$3_]T?__O=T[P"_<&L``"`!```N;```RFH``(06``!L%@``3_2`
M7`BUK>L,#,SX^`_^]V3O_O?"[@"Q`&@(O4_T@%SPM:WK#`S,^-@/)$HD3B5+
M>D2%L--8?D0%1@*I,$8;:`.33_```__W[?@0L0-X!$:+N1U*&TMZ1--8&F@#
MFUI`3_```RC1*4882'A$!;"]Z/!`__?3N2A&_O<B[P=&($;^]Q[O.$0",/[W
M,.X02Q%)*D9[1'E$`)0$1O[W`.\.2@A+>D336!IH`YM:0$_P``,$OR%&,$;9
MT/[W".\P:@``+A8``"`!```*:@``^A4``.(4``#D%```OFD``$_T@%PMZ?!/
MK>L,#,SXP`['L`WQR`K41M_X"!3?^`A$W_@()'E$BEA\1`3Q#`,$\1@.+*T2
M:$623_```@60D^@'`(7H!P"^Z`\`K.@/`)[H`P`P-`WQO`F,Z`,`E.@'`(GH
M!P#R2-_XS(,&KC%&>$3X1/_W:?@@L0-X!$8`*T#P5H'^][SN_O<:[@`H`/"2
M@`=H`"\`\(Z`.$;^]Z3N0``!,/[WMNTZ>`1&@49:L=_XB+/[1"!&64;^]X+N
M%_@!+P(T`"KVT=U(>$0"X%KX!`^(L3%&__<X^`1&`"CVT`-X`"OST/_W>/@`
M*._0($;^][SM!$9XN57X!$MDL2-X`"L`\`&!($;_]V?X`"CNT57X!$L`+/+1
M($;^]V3N!49(1O[W8.X%1`7R!$4H1O[W<.W-^`20@4;"2\))>T0`D\)+(D9[
M1'E$_O<\[D_TX'%(1O[W%.X!,`71_O<*[@!H$2A`\-B`,49(1O[W%NX$1@`H
M.-"V2`6:MDE8^```2T82:`!H>43^]\KM`"6R2J=+>D336!IH19M:0$_P``-`
M\#N!*$9'L+WH\(_^]U[M!T8`*$#PJX!9^`0+6+$Q1O[WQ/\`*/?0`W@`*^[1
M6?@$"P`H\]$-(/[W'.V?3U,B!$:!1G]$9.<S:0/T<$.S]8!/P-&W:?[W!.Z'
M0KO1,VG#\P@#L_7@?[71*$;^]P+M!4:32#%&>$3^]YC_`48`*`#PF8`%FQAH
M__<J^H)&`"@`\)&`4$;^]]CM`RB`1A#9B$D$.%!$>43^]\#L2+FX\00/`/#-
M@-!$&/@%/"\K`/#'@(%(,49X1/[W</\@L0-X,"L8OP`K!M$`(5!&_O?\[`9&
M`"AKT7E)>4AY1'A$__=9^/[WENQW2G=+>$EZ1-_XX(%X3WA.S>D``GM$2D8H
M1GE$_O>([?A$?T1^1!+@_O=:[0-H$2L4T?[W>NR$1@$T0T9*1CE&*$;-Z0%&
MS?@`P/[W<.U/].!Q*$;^]TKM`3#ET$A&_O=,[61(*49X1/_W(?@H1O_W'OY!
MYQQ&!>?^]VSM0``!,,;F34D%FECX`4!;21)H2T8`D'E$(&C^]_CL+.?_]P?^
M5TH]2WI$TU@::$6;6D!/\``#9]$@1D>PO>CP3_[WB;P%F]/X`*!JY__W0_VQ
M\0`(!T:-VT_P``JP\0H":/$``S!&S?@`H`WQX`O^]QCL!B(P1EE&_O?<[`8H
M1=%/](9#.)K$\D$SFD)_]'*O1/)(4[OX!"":0G_T:Z^W\3(":/$``S!&S?@`
MH#JL_O?XZR@B,$8A1O[WO.PH*"71,4HQ2S))>D0!DBA&2D8`E'M$>42-^!"A
M_O?L[(#G!9M?:``O/_0TKSA&_O?T[`,H?_8NKR=)!#@X1'E$_O?>ZP`H"+^Z
M1B/G_O?L[")(>$3_][G\`+]@:0``G&H``"`!```.%```%&D``.X4``!P%```
M>A0``&04``!B$P``_````'84``#V9P``N!,``#H4```2%```BA(``.(2``!D
M$@``H!0``/X1``#4$P``\A$``-P3``""%```A!$``)@2``!.9@``9!,``,80
M``"0$@``5!(``$@2``!/](!<<+6MZPP,S/CH#VM*:TMZ1--8@K`;:`&33_``
M`UU+'>YP3WM$&VCE6&5(E?AH,&E&>$2%^&DP;D;^]S#^$+$#>#$K>-#_]T;Z
M4TM[1!MHY5A<22A&`R,!(GE$_O?(ZP5&<+%.2P)I>T0;:!%H5DK@6'I$_O?(
MZRMI&6B+:%L";]1'2%))>$0`:`,C`2(@6'E$_O>LZP5&>+%-2#%&>$3^]_W]
M`D8`*$K0/DLI:7M$&V@):.!8_O>FZSM+1DE[1!MHY5@!(GE$*$;^]_CJ0DH!
M1GI$*$;^]Y;K-$L`(GM$&V@^2.-8,49X1(/X:2#^]];].TQ\1*!@H+%/].!Q
M_O?HZT,<$2@8OP$K.M@V2BM+>D336!IH`9M:0$_P``,NT0*P<+U@:/_W%OV@
M8``HY-$N2'A$_O?<ZD-X`"N)T(+G_O?-_QM+`D9[1!MH*6G@6!5&"6ABL?[W
M5NLH1O[WPNNKYQ1+>T0;:.!8_O?PZHCG'TM[1%MH&FC^]T;KG>?^]^+K&TH#
M1AM(>D32Z0$2>$0):/[WK.K*90``HF4``(9E``!H90``0&4``#!E```090``
MIF0``(ID``#*9```(`$``/0/``"@$0``C!$``'81``!`#P``1!$``%`1``#J
M#@``@F4``,IC``#X$```!&4``.YD``#`$```3_2`7#"UK>L,#,SXZ`\I2BE+
M>D0$1BE(@[#36&E&>$0;:`&33_```_[W//UPL0-X,"L8OP`K#+\!(P`C@_`!
M`P`L#+\`(P/P`0-;N1Q*&DMZ1--8&F@!FUI`3_```R?1`[`PO2-X`"OPT"!&
M__>J^"\A!4;^]Y+J`+%%'"A&_O>BZA!)!")Y1/[W?.H`*-W1#4H)2WI$TU@:
M:`&;6D!/\``#!=$@1@.PO>@P0/[W?KW^]TSKSF(``"`!```J#@``D&(``(H.
M``!,8@```````$_T@%PMZ?!/K>L,#,SX,`W?^)@IW_B8.7I$TUBM]2M]&VBI
MDT_P``,#1@BI`_&`!PI&`":\1@*00#!0Z0)T(PH#]']#)0)#ZA1C"#`%]'\%
M0^H$8S^Z*T.$1<+I`C968!=@`O$0`NC1W>DB0B:;#?&("0.3"IL*KB:O)*T`
MDP'U`G/-Z049!)<!DS!&`YNA1MWXE(#=^)S`W?@DL-WX+*#=^)#@#V@#E@>5
M`>"J1@"6`"70Z0X44/@(;T5G16AQ0('J"0%L0'E`5$"$Z@L$\4:>1LL/0^I$
M`TD8"T,!F4)&B$+@1M-&3_``#`"?`V?=T0.>W>D%&0>=,VC5^`#@`Y,$FPAH
M'&@"FT?VF1*=:-/X`(`I1AU&T_@0H-/X&+!?:"YJVVB-"-GX`,`!ED7J@W6*
MZ@L)Q?:"(D7J@74`D0GJ`0E/ZMAF`9E&ZD<6@!A`&$;J2!8#F4_JF`.)Z@L)
M0^J'<S88BNH%!Q;K"08'Z@@'B1B'Z@H'$>L+`4/JB'/(&0R9A>H#!XD8-T!O
M0!'K"@$`Z_9@R1D!Z_!I#IF)&$D9@^JV!05`74!/ZK``21D0G8#JM@>M&`?J
M"0>'ZK8'[1@!Z_EA[1D%Z_%G$IU.]J$SK1@%Z[8%@.JY!@Y`1D"M&12>3^JQ
M`;88,!B!ZKD&/D"&ZKD&!>OW98`9`.OU9A:8QO;98X`8`.NY`('JMPD)Z@4)
MB>H!"1#K"0#=^&"03^JU!1GK`@D9ZP$!A>JW"0GJ!@F)ZK<)`.OV8!'K"0$!
MZ_!I&IF)&`'KMP&%ZK8'!T!O0,D9`>OY9QR93^JP`(D821F`ZK8%!>H)!87J
MM@5)&0'K]V4>F8D8`>NV`8#JN08^0$9`B1D!Z_5F()E/ZK<'B1@(&(?JN0$I
M0('JN0%!&!SK`@`!Z_9LA^JU`3%``.NY`'E`3^JV!D$8'NL"`,`9`>O\9X;J
MM0$!Z@P!@>JU`4$8H!B&ZKP$/$!T0`#KM0`!Z_=A`!E/ZK<'`.OQ9"B8A^J\
M!8`8#4"%ZKP%@!E`&0#K]&4JF(?JL0:`&"9`?D``Z[P`@!DLGD_JM`2V&/89
MA.JQ!R]`A^JQ!P#K]6#V&0;K\&<NGK(8A.JU!@+KL0(&0$_JL`$PF&9`DAG`
M&#*>`!F!ZK4$?$`$&?`8`NOW8H'JMP8`Z[4`-)U60`3K\F2`&4_JL@+M&&D8
M@NJW!C:=9D".&>D8`.OT8#B=`>NW`8+JM`<&Z_!F1T!/ZK``R1F`ZK0,.I_M
M&(SJ!@RM&!7K#`7_&`'K]F&`ZK8,!^NT!SR<C.H!#`7K\647ZPP'3^JQ`>08
M@>JV#"08!^OU8#Z?C.H%#!3K#`3_&('JM0P'Z[8'0)Z,Z@`,!.OP9!?K#`=/
MZK``]AAV&(#JM0P'Z_1A0I^,Z@0,%NL,#$OVW$+_&$2>!^NU!PSK\66`ZK0,
MC.H!#!?K#`=/ZK$!]A@V&('JM`P'Z_5@1I^,Z@4,%NL,#/\82)X'Z[0'#.OP
M9('JM0R,Z@`,%^L,!T_JL`#V&'88@.JU#`?K]&%*GXSJ!`P6ZPP,_QA,G@?K
MM0<,Z_%E@.JT#(SJ`0P7ZPP'3^JQ`?88-AB!ZK0,!^OU8$Z?C.H%#!;K#`S_
M&%">!^NT!PSK\&2!ZK4,C.H`#!?K#`=/ZK``]AAV&(#JM0P'Z_1A4I^,Z@0,
M%NL,#/\85)X'Z[4'#.OQ98#JM`R,Z@$,%^L,!T_JL0'V&('JM`PV&`?K]6!6
MGXSJ!0P6ZPP&_Q@'Z[0,6)N!ZK4$R/8;<D_JL`=$0`;K\&8<ZP0$1^JU`)L8
M!^JU#%D8,$`$Z_9C6IQ`Z@P`"!BD&`3KM04`Z_-D1^JV``?JM@P80%R93^JS
M`T#J#`!`&4/JM@4#ZK8,B1@E0,D91>H,!5Z?`.OT8&T80^JT`0/JM`R_&`%`
M!>OP90?KM@=/ZK``8)Y!Z@P!R1E`ZK0'`.JT#MWXB,&V&"]`]AA'Z@X'OQD<
MZP(,`>OU80SKM`Q`ZK4$9)X`ZK4.#$!$Z@X$!^OQ9Q3K#`1/ZK$!MA@P&$'J
MM08!ZK4.W?B8P3Y`1NH.!@3K]V0V&!SK`@Q!ZK<``>JW#@SKM0P@0&B=0.H.
M``;K]&80ZPP`3^JT!*T8:1A$ZK<%!.JW#MWXJ,$U0$7J#@5M&!SK`@P`Z_9@
M#.NW#$3JM@<$ZK8.;)D'0$?J#@<%Z_!E%^L,#$_JL`")&`\9#.OU9$#JM@P`
MZK8.;ID,Z@4,3.H.#!SK!P>)&`'KM@Q`ZK4&`.JU#G"9)D!&Z@X&!^OT9Q;K
M#`Q/ZK0$B1@.&`SK]V!$ZK4,!.JU#G*9#.H'#$SJ#@P<ZP8&B1@!Z[4,1.JW
M!03JMPYTF05`1>H.!0;K\&85ZPP,3^JP`(D8#1D,Z_9D0.JW#`#JMPYVF0SJ
M!@Q,Z@X,'.L%!8D8`>NW#$#JM@<`ZK8.)T!'Z@X'%^L,#``G3/+6$WB9!>OT
M98D83^JT!!'K``D"F`SK]6%$ZK8,!.JV#D=@QV!'8<=A#.H%#'J83.H.#!SK
M"0>`&`#KM@Q$ZK4&!.JU#GR8#D!&Z@X&!^OQ9Q;K#`9/ZK$!@!@0ZP0,!NOW
M9$'JM08!ZK4.?I@^0$;J#@86ZPP,@!@`Z[4&0>JW``SK]&6`F@'JMPP@0,SV
M8B-`Z@P`3^JT!(`9TAB$ZK<&41B"FFY`B1G2&`#K]6`"Z[<&A.JU!X2:1T`!
MZ_!A]AE/ZK``TAB`ZK4'%!F&FD]`Y!G2&`;K\68"Z[4%@.JQ!XB:=T`$Z_9D
M[QE/ZK8%TA@6&`?K]&"*FH7JL0=G0/<9TA@"Z[$&!^OP88R:A>JT!T=`]AE/
MZK``TAA7&0;K\66.FH#JM`9.0+\9TA@"Z[0&!^OU9)":@.JQ!V]`]AE/ZK4%
MTA@7&`;K]&"2FH7JL09F0+\9TA@"Z[$&!^OP892:A>JT!T=`]AE/ZK``TAA7
M&0;K\666FH#JM`9.0+\9TA@"Z[0&!^OU9)B:@.JQ!V]`]AE/ZK4%TA@7&)J:
M!NOT8(7JL09F0+\9TA@"Z[$&!^OP89R:A>JT!T=`]AE/ZK``TAB`ZK0'51F>
MFD]`[1G7&`;K\68'Z[0'H)J`ZK$$=$`%Z_9E/QE/ZK8$TA@6&`?K]6"BFH3J
ML0=O0/<9TA@"Z[$&!^OP80*?"^NQ`KIAA.JU!T=`I)KV&0;K\6;2&`*?3^JP
M`!09"NNV`CIA@.JU!Z::3T#D&=(8$NL(`@+KM0.`ZK$"<D";&`&9`)H"GP3K
M]F2B&`/K]&-`&#M@NF`X8CM&`"<*2E]B"$MZ1--8&FBIFUI`3_```P/1#?4K
M?;WH\(_]]VKN`+_X80``(`$``()8``!/](!<"+6MZPP,S/CX#X`@_?=H[9_M
M#GN`[0![G^T.>X#M`GN?[0Y[@.T$>Y_M#GN`[09[G^T.>X#M"'N?[0Y[`"*`
M[0I[@.T,>X)G"+T`OP$C16<`````B:O-[P````#^W+J8`````'94,A``````
M\.'2PP```````````````$_T@%PMZ?!'K>L,#,SXX`\71@5&`".$:HA&T.D,
M(03KQP:F0NQJ3^KG<'/K!`0"T@$R0?$``<7I"F-[#T/JP`.;&$'K4'&H;RMC
M:6,%\3@&X+'`\4`$!?$X!KQ",$2HOSQ&0$52TPCK!`D!V4A%2--!1B)&_??4
M[:MO(T1`*ZMG.=$H1O_WH/K(1C\;/R\EW41&!?%X"0CQ0`JF0BW23$4OT]!&
M,T8$\4`"U/@`X-3X!,"@:.%H$#240L/X`.##^`3`F&#98`/Q$`/NT2A&0#__
M]WKZ/R\*\4`*WMQ&11'3`]D(ZP<#GD(+TSI&048P1OWWENVO9[WH\(?01M+9
M5D70TO_>\QF81>_2_]X#&9A%*+\(ZP0)J]+_W@"_3_2`7"WI\$&MZPP,S/CH
M#T_P@`R*:@'Q.`>2^H+XPO/%`@MK!_@"P`$R."H%1@Q&'KH'ZP(`1-T`(<+Q
M0`+]]W+L($;_]S+Z."(`(3A&_?=J["!&Q.D<:/_W*/KC>"!&*W!CB&MP(V@;
M"JMP(VCK<.-Z*W%CB6MQHV@;"JMQHVCK<>-\*W)CBFMR(VD;"JMR(VGK<N-^
M*W-CBVMSHVD;"JMSHVGK<Y3X(S`K=&.,:W0C:AL*JW0C:NMTO>CP0?WW_[P`
M(<+Q.`+]]RSLP><`OP&UO>@!0'!'/@```$$````,````00```!$```!!````
M)P```$$````V````00````,```!!````!@```$$````5````00````\```!!
M````#@```$$````F````00```!,```!!````*0```$$````"````00```!D`
M``!!````"@```$$````+````00``````````````)7,O)7,```!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````
M+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`
M````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/
M4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%2
M7T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$
M14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````#$```!L<V5E:R!F86EL
M960`````<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R
M>``````E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO
M=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R
M;``````N<&%R`````'-H;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S
M=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8````<&5R;``````P
M````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-C,```!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`````"UE```M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O
M=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D
M0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C
M:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S
M:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@
M(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K
M*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B
M4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@
M/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY
M("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE
M+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L
M=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K
M("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@
M;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L
M("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O
M<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M
M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@
M)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D[
M"F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL
M93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL
M:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P
M87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@
M1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I
M;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC
M;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL
M96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM
M;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E
M=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D
M(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE
M;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@
M:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R
M7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D[
M"E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B
M)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?
M1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M
M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B
M72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO
M+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA
M9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG
M="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R
M;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I
M8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?
M<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@
M,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U
M9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B
M3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ
M<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F
M+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L
M("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D
M;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@
M=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T
M.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@
M(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L
M;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X
M="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL
M;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I
M;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]
M"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@
M*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@
M;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5]
M.PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U
M;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D
M92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P
M*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[
M9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL
M96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG
M="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D
M9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N
M;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.
M+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D
M9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N
M86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U
M:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'
M24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N
M(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T
M7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T
M(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L
M<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`
M05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I
M<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS
M:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@
M1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II
M<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@
M9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G
M345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@
M/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M
M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D
M<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE0
M7TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F
M:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP
M-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A
M73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R
M.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@
M7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@
M=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN
M8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)3
M1%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG
M.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D
M?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@
M0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*
M;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@
M("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E
M86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D
M;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD[
M"GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]
M?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK
M+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L*
M*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B
M)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D[
M"FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X
M="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A
M;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H
M<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^
M>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I
M*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^
M.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C
M;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F
M:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L
M96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G
M3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T
M<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z
M:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U
M=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP
M0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2![
M"FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@
M,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE
M7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S
M='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N
M86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD[
M"GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD
M9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@
M(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N
M9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF
M9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A
M8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES
M1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@[
M"FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z
M.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I
M.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M
M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA
M;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI
M.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@
M=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE
M3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO
M<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S
M=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY
M("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(
M*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C
M:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B
M=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O
M9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*
M:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@
M,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE
M"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D
M8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*
M+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E
M860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O
M+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@[
M"GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E
M;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM0
M05)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D
M92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N
M;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA
M;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE
M*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@
M)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E
M;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E
M='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%
M?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\
M/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L
M("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q
M*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA
M;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\
M)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D
M<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE
M?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I
M<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E
M=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S
M+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO
M.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?
M:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@
M*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@
M,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@
M4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H
M<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?
M(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!
M4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E
M("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q
M=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L
M<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E
M($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG
M.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A
M<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*
M*3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L
M(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE
M('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE
M(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R
M;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]
M?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?
M7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)2
M3U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`````$-!
M0TA%```^````00````P```!!````$0```$$````G````00```#8```!!````
M`P```$$````&````00```!4```!!````#P```$$````.````00```"8```!!
M````$P```$$````I````00````(```!!````&0```$$````*````00````L`
M``!!````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````!)%@``Y14```$````6`P``
M`0```"$#```=````=00```P```!9$```#0```-4X```9````S(T``!L````$
M````&@```-"-```<````!````/7^_V]P`0``!0```/P(```&````7`(```H`
M``"3!```"P```!`````5``````````,```#$C@```@```-@!```4````$0``
M`!<```"`#@``$0```)`-```2````\````!,````(````'@````@```#[__]O
M`0``"/K__V\0````````````````````````````````````````````````
M`````````-2-`````````````&`0``!@$```8!```&`0``!@$```8!```&`0
M``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!``
M`&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```
M8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@
M$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0``!@$```8!```&`0
M``!@$```8!```&`0``!@$```8!```&`0``!@$```21,`````````````U3@`
M````````````61``````````````````````````````````````````````
M````````````D```"E!!4BYP;0H`````I#P``+@Y````````>#H``'PZ``"8
M/```P#D``*`\````````A#P``(P\````````K#P``$=#0SH@*$%L<&EN92`Q
M-"XR+C`I(#$T+C(N,`!!,@```&%E86)I``$H````!3<M00`&"@=!"`$)`@H$
M$@03`10!%0$7`Q@!&@(<`1X"(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;"YD
M>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A
M;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T
M80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````````````
M``````````````````````````````````````L````!`````@```#0!```T
M`0``&````````````````0`````````3````!P````(```!,`0``3`$``"0`
M``````````````0`````````)@```/;__V\"````<`$``'`!``#L````!```
M```````$````!````#`````+`````@```%P"``!<`@``H`8```4````#````
M!````!`````X`````P````(```#\"```_`@``),$``````````````$`````
M````0`````D````"````D`T``)`-``#P````!``````````$````"````$D`
M```)````0@```(`.``"`#@``V`$```0````1````!`````@```!2`````0``
M``8```!8$```6!````@```````````````(`````````30````$````&````
M8!```&`0``#D`@`````````````$````!````%@````!````!@```$@3``!(
M$P``C"4`````````````"`````````!>`````0````8```#4.```U#@```@`
M``````````````(`````````9`````$````"````W#@``-PX``#D00``````
M```````$`````````&P````!`````@```,!Z``#`>@``!```````````````
M!`````````!V````#@````,```#,C0``S'T```0```````````````0````$
M````@@````\````#````T(T``-!]```$```````````````$````!````(X`
M```&`````P```-2-``#4?0``\`````4`````````!`````@```"7`````0``
M``,```#$C@``Q'X``#P!``````````````0````$````G`````$````#````
M`)````"```!$```````````````$`````````*(````(`````P```$20``!$
M@```+```````````````!`````````"G`````0```#``````````1(```!P`
M``````````````$````!````L`````,``'```````````&"````S````````
M```````!``````````$````#``````````````"3@```P```````````````
(`0``````````
